import S3 from "aws-sdk/clients/s3";
import Thumbnail, { S3Thumbnail, ThumbnailConfig } from "./thumbnail";
interface ThumbnailerConfig {
    ffmpegPath?: string;
    bucket?: string;
    allowedFileTypes: string[];
}
/**
 * Interface for a S3 bucket
 */
interface S3Bucket {
    name: string;
    ownerIdentity: Object;
    arn: string;
}
/**
 * Interface for a S3 object
 */
interface S3Object {
    key: string;
    size: number;
    eTag: string;
    sequencer: string;
}
/**
 * Interface for a S3 object record
 */
export interface S3Record {
    s3SchemaVersion: number;
    configurationId: string;
    bucket: S3Bucket;
    object: S3Object;
}
/**
 * Base Thumbnailer class that generates a thumbnail from a video file
 * @param {string} filePath - Path to the video file
 * @param {string} output - Full Path to the output thumbnail (no file extension required), if you specify one it will be used
 * @param {ThumbnailConfig} config - Thumbnail configuration
 */
export default class Thumbnailer {
    protected config: ThumbnailerConfig;
    private input;
    private output;
    constructor(input: string, output?: string, config?: ThumbnailerConfig);
    createThumbnail(config?: ThumbnailConfig): Promise<any>;
    generateThumbnail(thumbnail: Thumbnail): Promise<any>;
    private getOutputPath;
}
/**
 * Thumbnailer class that generates a thumbnail from a video file
 * @param {S3Record} s3record - S3 Record generated from an event
 * @param {S3Config} config - S3 configuration object
 * @param {ThumbnailConfig} config - Thumbnail configuration
 */
export declare class S3Thumbnailer extends Thumbnailer {
    private key;
    private bucket;
    private client;
    constructor(s3Record: S3Record, S3Config?: S3.ClientConfiguration, config?: ThumbnailerConfig);
    createThumbnail(config?: ThumbnailConfig): Promise<string>;
    setS3Options(config: S3.ClientConfiguration): void;
    generateThumbnail(thumbnail: S3Thumbnail): Promise<string>;
    getKey(): string;
    getBucket(): string;
    setKey(key: string): ThisType<S3Thumbnailer>;
    setBucket(bucket: string): ThisType<S3Thumbnailer>;
}
export {};
