"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isValidType = exports.getFileName = exports.getNewName = exports.decodeKey = void 0;
/**
 * This function decodes an s3 url encoded string replacing + with spaces
 * @param {string} key s3 url-encoded string
 * @returns {string} decoded string
 */
var decodeKey = function (key) { return decodeURIComponent(key).replace(/\+/g, " "); };
exports.decodeKey = decodeKey;
/**
 * This function returns the new filename with the new extension
 * @param {string} key The key/filename of the original file
 * @param {string} type The filetype of the screenshot/thumbnail
 * @returns {string} the new filename with the correct extension
 */
var getNewName = function (key, type) { if (key.match(/\.\w+$/))
    return key.replace(/\.\w+$/, "." + type); return key + "." + type; };
exports.getNewName = getNewName;
/**
 * This function gets the filename without an extension
 * @param key The key/filename of the original file
 * @returns {string} filename without any extension
 */
var getFileName = function (key) { return key.replace(/\.\w+$/, ""); };
exports.getFileName = getFileName;
/**
 * This function checks if a filename has a type in the list of allowed extensions
 * @param filename The filename to be checked
 * @param types The array of filetypes/extensions to be checked against
 * @returns {boolean} true if the filename is of the correct type
 */
var isValidType = function (filename, types) { var type = filename.toLowerCase().match(/\.\w+$/); if (!type)
    return false; var ft = type[0].substr(1); return types.indexOf(ft) !== -1; };
exports.isValidType = isValidType;
